<h3 align="center">
  <a name="readme-top"></a>
  <img
    src="https://docs.arcade-ai.com/images/logo/arcade-ai-logo.png"
  >
</h3>
<div align="center">
  <h3>LangChain Integration</h3>
    <a href="https://github.com/arcadeai/arcade-ai/blob/main/LICENSE">
  <img src="https://img.shields.io/badge/License-MIT-yellow.svg" alt="License">
</a>
    <a href="https://pepy.tech/project/langchain-arcade">
  <img src="https://static.pepy.tech/badge/langchain-arcade" alt="Downloads">
</a>

</div>

<p align="center">
    <a href="https://docs.arcade-ai.com" target="_blank">Docs</a> •
    <a href="https://docs.arcade-ai.com/integrations" target="_blank">Integrations</a> •
    <a href="https://github.com/ArcadeAI/cookbook" target="_blank">Cookbook</a> •
    <a href="https://github.com/ArcadeAI/arcade-py" target="_blank">Python Client</a> •
    <a href="https://github.com/ArcadeAI/arcade-js" target="_blank">JavaScript Client</a>
</p>

## Overview

`langchain-arcade` allows you to use Arcade AI tools in your LangChain and LangGraph applications.

## Installation

```bash
pip install langchain-arcade
```

## Usage

See the [examples](https://github.com/ArcadeAI/arcade-ai/tree/main/examples/langchain) for usage examples
